@@ -120,11 +120,11 @@ matrixpls.plspm <-
     
     if(scaled){
       dataToUse <- scale(dataToUse)
-      S <- stats::cor(dataToUse)
+      S <- stats::cor(dataToUse, use = "complete.obs")
       S_std <- S
     }
     else{
-      S <- stats::cov(dataToUse)
+      S <- stats::cov(dataToUse, use = "complete.obs")
       S_std <- stats::cov2cor(S)
     } 
     
@@ -205,8 +205,9 @@ matrixpls.plspm <-
     
     outer.mod <- sapply(lvNames, function(lvName){
       row <- which(lvNames == lvName)
-      weights <- W[row,params$outer[[row]]] *sdv
-      std.loads <- IC_std[row,params$outer[[row]]]
+      colnames <-colnames(Data)[params$outer[[row]]]
+      weights <- W[row,colnames] *sdv
+      std.loads <- IC_std[row,colnames]
       communal <- std.loads^2
       redundan <- communal * R2[row]
       
